Learn R Programming

ssdtools (version 2.7.0)

glance.fitdists: Get a tibble summarizing each distribution

Description

Gets a tibble with a single row for each distribution.

Usage

# S3 method for fitdists
glance(x, ..., wt = FALSE)

Value

A tidy tibble of the distributions.

Arguments

x

The object.

...

Unused.

wt

A flag specifying whether to return the Akaike weight as "wt" instead of "weight".

Details

The aicc is Inf if the number of observations is less than the number of parameters plus two as the small sample size correction is undefined.

See Also

ssd_gof()

Other generics: augment.fitdists(), tidy.fitdists()

Examples

Run this code
fits <- ssd_fit_dists(ssddata::ccme_boron)
glance(fits, wt = TRUE)

Run the code above in your browser using DataLab