Gets a tibble with a single row for each distribution.
Usage
# S3 method for class 'fitdists'
glance(x, ..., wt = FALSE)Details
The aicc is Inf if the number of observations is less than
the number of parameters plus two as the small sample size
correction is undefined.
See also
Other generics:
augment.fitdists(),
tidy.fitdists()
Examples
fits <- ssd_fit_dists(ssddata::ccme_boron)
glance(fits, wt = TRUE)
#> # A tibble: 6 × 8
#> dist npars nobs log_lik aic aicc delta wt
#> <chr> <int> <int> <dbl> <dbl> <dbl> <dbl> <dbl>
#> 1 gamma 2 28 -117. 238. 238. 0.00503 0.357
#> 2 lgumbel 2 28 -120. 244. 245. 6.56 0.0134
#> 3 llogis 2 28 -119. 241. 241. 3.39 0.0656
#> 4 lnorm 2 28 -118. 239. 240. 1.40 0.177
#> 5 lnorm_lnorm 5 28 -115. 240. 243. 4.98 0.0296
#> 6 weibull 2 28 -117. 238. 238. 0 0.357