powered by
Gets a tibble with a single row for each distribution.
# S3 method for fitdists glance(x, ..., wt = FALSE)
A tidy tibble of the distributions.
The object.
Unused.
A flag specifying whether to return the Akaike weight as "wt" instead of "weight".
The aicc is Inf if the number of observations is less than the number of parameters plus two as the small sample size correction is undefined.
aicc
Inf
ssd_gof()
Other generics: augment.fitdists(), tidy.fitdists()
augment.fitdists()
tidy.fitdists()
fits <- ssd_fit_dists(ssddata::ccme_boron) glance(fits, wt = TRUE)
Run the code above in your browser using DataLab