ssd_fit_bcanz: Fit BCANZ Distributions
Description
Fits distributions using settings adopted by
BC, Canada, Australia and New Zealand for official guidelines.
Usage
ssd_fit_bcanz(
data,
left = "Conc",
...,
dists = ssd_dists_bcanz(),
rescale = FALSE,
silent = FALSE
)
Value
An object of class fitdists.
Arguments
- data
A data frame.
- left
A string of the column in data with the concentrations.
- ...
Unused.
- dists
A character vector of the distribution names.
- rescale
A flag specifying whether to leave the values unchanged (FALSE) or to rescale concentration values by dividing by the geometric mean of the minimum and maximum positive finite values (TRUE).
- silent
A flag indicating whether fits should fail silently.
See Also
ssd_fit_dists()
Other BCANZ:
ssd_hc_bcanz(),
ssd_hp_bcanz()
Examples
Run this codessd_fit_bcanz(ssddata::ccme_boron)
Run the code above in your browser using DataLab