Gets hazard concentrations with confidence intervals that protect
1, 5, 10 and 20% of species using settings adopted by
BC, Canada, Australia and New Zealand for official guidelines.
This function can take several minutes to run with recommended 10,000 iterations.
A numeric vector of proportion values to estimate hazard concentrations for.
...
Unused.
average
A flag specifying whether to provide model averaged values as opposed to a value for each distribution.
ci
A flag specifying whether to estimate confidence intervals (by bootstrapping).
nboot
A count of the number of bootstrap samples to use to estimate the confidence limits. A value of 10,000 is recommended for official guidelines.
min_pboot
A number between 0 and 1 of the minimum
proportion of bootstrap samples that must successfully fit (return a likelihood)
to report the confidence intervals.